@@ -66,13 +66,13 @@ def api_method(func):
             try:
                 project = Project.objects.get_from_cache(**lookup_kwargs)
             except Project.DoesNotExist:
-                return HttpResponse('Invalid project_id: %r' % project_id, status_code=400)
+                return HttpResponse('Invalid project_id: %r' % project_id, status=400)
         else:
             project = None
 
         origin = request.META.get('HTTP_ORIGIN', None)
         if origin is not None and not is_valid_origin(origin, project):
-            return HttpResponse('Invalid origin: %r' % origin, status_code=400)
+            return HttpResponse('Invalid origin: %r' % origin, status=400)
 
         response = func(request, project, *args, **kwargs)
         response = apply_access_control_headers(response, origin)
@@ -172,12 +172,12 @@ def store(request, project=None):
 
             insert_data_to_database(data)
         except APIError, error:
-            logger.error('Client %r raised API error: %s' % (client, error), extra={
+            logger.error('Client %r raised API error: %s', client, error, extra={
                 'request': request,
             }, exc_info=True)
             response = HttpResponse(unicode(error.msg), status=error.http_status)
         else:
-            logger.info('New event from client %r (id=%%s)' % client, data['event_id'])
+            logger.info('New event from client %r (id=%%s)', client, data['event_id'])
 
     return response
 
